// ======================================================================
//
// Control.h
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#ifndef CONTROL_H
#define CONTROL_H

// ======================================================================

class Iff;
class Object;

#include "ControlMessageQueue.h"

// ======================================================================

class Control
{
protected:

	Object              *owner;
	ControlMessageQueue *queue;
	real                 elapsedTime;        // time since last alter/update/think triad

public:

	explicit Control(Object *newOwner=NULL);
	virtual ~Control(void);

	virtual void  setOwner(Object *newOwner);
	const Object *getOwner(void) const;
	Object       *getOwner(void);

	virtual void  createPacket(Iff &iff);
	virtual void  processPacket(Iff &iff);

	virtual void  prepare(real time);
	virtual void  update(void);
	virtual void  alter(void);

	const ControlMessageQueue *getControlMessageQueue(void) const;

	// allows the user to add messages to the control message queue
	void event(ControlMessage message, real value, void *data=NULL);
};

// ======================================================================

inline const Object *Control::getOwner(void) const
{
	return owner;
}

// ----------------------------------------------------------------------

inline Object *Control::getOwner(void)
{
	return owner;
}

// ----------------------------------------------------------------------

inline const ControlMessageQueue *Control::getControlMessageQueue(void) const
{
	return queue;
}

// ----------------------------------------------------------------------

inline void Control::event(ControlMessage message, real value, void *data)
{
	queue->event(message, value, data);
}

// ======================================================================

#endif
